pub struct DeleteMemoryInput {
pub memory_id: String,
pub reason: Option<String>,
}Fields
memory_id: Stringreason: Option<String>Trait Implementations
Sourceimpl Debug for DeleteMemoryInput
impl Debug for DeleteMemoryInput
Sourceimpl<'de> Deserialize<'de> for DeleteMemoryInput
impl<'de> Deserialize<'de> for DeleteMemoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeleteMemoryInput
impl JsonSchema for DeleteMemoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteMemoryInput
impl RefUnwindSafe for DeleteMemoryInput
impl Send for DeleteMemoryInput
impl Sync for DeleteMemoryInput
impl Unpin for DeleteMemoryInput
impl UnsafeUnpin for DeleteMemoryInput
impl UnwindSafe for DeleteMemoryInput