pub struct GetSessionStateInput {
pub session_id: String,
}Fields
session_id: StringTrait Implementations
Sourceimpl Debug for GetSessionStateInput
impl Debug for GetSessionStateInput
Sourceimpl<'de> Deserialize<'de> for GetSessionStateInput
impl<'de> Deserialize<'de> for GetSessionStateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetSessionStateInput
impl JsonSchema for GetSessionStateInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetSessionStateInput
impl RefUnwindSafe for GetSessionStateInput
impl Send for GetSessionStateInput
impl Sync for GetSessionStateInput
impl Unpin for GetSessionStateInput
impl UnsafeUnpin for GetSessionStateInput
impl UnwindSafe for GetSessionStateInput