pub struct ListSessionEventsInput {
pub session_id: String,
pub event_types: Option<Vec<EventType>>,
pub limit: Option<usize>,
}Fields
session_id: Stringevent_types: Option<Vec<EventType>>limit: Option<usize>Trait Implementations
Sourceimpl Debug for ListSessionEventsInput
impl Debug for ListSessionEventsInput
Sourceimpl<'de> Deserialize<'de> for ListSessionEventsInput
impl<'de> Deserialize<'de> for ListSessionEventsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListSessionEventsInput
impl JsonSchema for ListSessionEventsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListSessionEventsInput
impl RefUnwindSafe for ListSessionEventsInput
impl Send for ListSessionEventsInput
impl Sync for ListSessionEventsInput
impl Unpin for ListSessionEventsInput
impl UnsafeUnpin for ListSessionEventsInput
impl UnwindSafe for ListSessionEventsInput