pub struct RedactMemoryInput {
pub memory_id: String,
pub redacted_content: String,
pub fields_removed: Option<Vec<String>>,
}Fields
memory_id: Stringredacted_content: Stringfields_removed: Option<Vec<String>>Trait Implementations
Sourceimpl Debug for RedactMemoryInput
impl Debug for RedactMemoryInput
Sourceimpl<'de> Deserialize<'de> for RedactMemoryInput
impl<'de> Deserialize<'de> for RedactMemoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RedactMemoryInput
impl JsonSchema for RedactMemoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RedactMemoryInput
impl RefUnwindSafe for RedactMemoryInput
impl Send for RedactMemoryInput
impl Sync for RedactMemoryInput
impl Unpin for RedactMemoryInput
impl UnsafeUnpin for RedactMemoryInput
impl UnwindSafe for RedactMemoryInput