pub struct ResumeSessionInput {
pub session_id: String,
pub resume_payload: Option<Value>,
pub reason: Option<String>,
}Fields
session_id: Stringresume_payload: Option<Value>reason: Option<String>Trait Implementations
Sourceimpl Debug for ResumeSessionInput
impl Debug for ResumeSessionInput
Sourceimpl<'de> Deserialize<'de> for ResumeSessionInput
impl<'de> Deserialize<'de> for ResumeSessionInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResumeSessionInput
impl JsonSchema for ResumeSessionInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeSessionInput
impl RefUnwindSafe for ResumeSessionInput
impl Send for ResumeSessionInput
impl Sync for ResumeSessionInput
impl Unpin for ResumeSessionInput
impl UnsafeUnpin for ResumeSessionInput
impl UnwindSafe for ResumeSessionInput