pub struct RetrieveMemoryInput {
pub subject_type: String,
pub subject_id: String,
pub query: Option<String>,
pub memory_types: Option<Vec<MemoryType>>,
pub limit: Option<usize>,
}Fields
subject_type: Stringsubject_id: Stringquery: Option<String>memory_types: Option<Vec<MemoryType>>limit: Option<usize>Trait Implementations
Sourceimpl Debug for RetrieveMemoryInput
impl Debug for RetrieveMemoryInput
Sourceimpl<'de> Deserialize<'de> for RetrieveMemoryInput
impl<'de> Deserialize<'de> for RetrieveMemoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RetrieveMemoryInput
impl JsonSchema for RetrieveMemoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetrieveMemoryInput
impl RefUnwindSafe for RetrieveMemoryInput
impl Send for RetrieveMemoryInput
impl Sync for RetrieveMemoryInput
impl Unpin for RetrieveMemoryInput
impl UnsafeUnpin for RetrieveMemoryInput
impl UnwindSafe for RetrieveMemoryInput