pub struct StoreMemoryInput {
pub memory_type: MemoryType,
pub subject_type: String,
pub subject_id: String,
pub content: String,
pub data_class: Option<DataClass>,
pub source_session_id: Option<String>,
pub confidence: Option<f64>,
}Fields
memory_type: MemoryTypesubject_type: Stringsubject_id: Stringcontent: Stringdata_class: Option<DataClass>source_session_id: Option<String>confidence: Option<f64>Trait Implementations
Sourceimpl Debug for StoreMemoryInput
impl Debug for StoreMemoryInput
Sourceimpl<'de> Deserialize<'de> for StoreMemoryInput
impl<'de> Deserialize<'de> for StoreMemoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoreMemoryInput
impl JsonSchema for StoreMemoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreMemoryInput
impl RefUnwindSafe for StoreMemoryInput
impl Send for StoreMemoryInput
impl Sync for StoreMemoryInput
impl Unpin for StoreMemoryInput
impl UnsafeUnpin for StoreMemoryInput
impl UnwindSafe for StoreMemoryInput