pub struct TerminateSessionInput {
pub session_id: String,
pub reason: String,
pub reason_code: Option<String>,
}Fields
session_id: Stringreason: Stringreason_code: Option<String>Trait Implementations
Sourceimpl Debug for TerminateSessionInput
impl Debug for TerminateSessionInput
Sourceimpl<'de> Deserialize<'de> for TerminateSessionInput
impl<'de> Deserialize<'de> for TerminateSessionInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TerminateSessionInput
impl JsonSchema for TerminateSessionInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TerminateSessionInput
impl RefUnwindSafe for TerminateSessionInput
impl Send for TerminateSessionInput
impl Sync for TerminateSessionInput
impl Unpin for TerminateSessionInput
impl UnsafeUnpin for TerminateSessionInput
impl UnwindSafe for TerminateSessionInput