pub struct UpdateMemoryInput {
pub memory_id: String,
pub content: String,
pub reason: Option<String>,
}Fields
memory_id: Stringcontent: Stringreason: Option<String>Trait Implementations
Sourceimpl Debug for UpdateMemoryInput
impl Debug for UpdateMemoryInput
Sourceimpl<'de> Deserialize<'de> for UpdateMemoryInput
impl<'de> Deserialize<'de> for UpdateMemoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateMemoryInput
impl JsonSchema for UpdateMemoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateMemoryInput
impl RefUnwindSafe for UpdateMemoryInput
impl Send for UpdateMemoryInput
impl Sync for UpdateMemoryInput
impl Unpin for UpdateMemoryInput
impl UnsafeUnpin for UpdateMemoryInput
impl UnwindSafe for UpdateMemoryInput